@@ -1,7 +1,9 @@
 from TimeConvert.convert import TC, TimeConvert, tc
+from TimeConvert.isoweek import ISOWeek
 from TimeConvert.month import Month
 from TimeConvert.quarter import Quarter
 from TimeConvert.stopwatch import StopWatch, TimeType
+from TimeConvert.week import Week
 
 
 __all__ = [
@@ -10,6 +12,8 @@ __all__ = [
     'TimeConvert',
     'Month',
     'Quarter',
+    'Week',
+    'ISOWeek',
     'StopWatch',
     'TimeType'
 ]
